@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::authors_by_rdep_count;
 
-our $DATE = '2016-10-09'; # DATE
-our $VERSION = '1.009'; # VERSION
+our $DATE = '2016-10-14'; # DATE
+our $VERSION = '1.010'; # VERSION
 
 use 5.010;
 use strict;
@@ -20,6 +20,9 @@ $SPEC{'handle_cmd'} = {
         %App::lcpan::common_args,
         clone_list(%App::lcpan::deps_phase_args),
         clone_list(%App::lcpan::deps_rel_args),
+        exclude_same_author => {
+            schema => 'bool',
+        },
     },
 };
 delete $SPEC{'handle_cmd'}{args}{phase}{default};
@@ -40,15 +43,20 @@ sub handle_cmd {
         push @where, "(rel=?)";
         push @binds, $args{rel};
     }
+    push @where, "d.is_latest";
+    push @where, "d.cpanid <> m.cpanid" if $args{exclude_same_author};
     @where = (1) if !@where;
 
     my $sql = "SELECT
   m.cpanid id,
+  a.fullname name,
   COUNT(*) AS rdep_count
 FROM module m
 JOIN dep dp ON dp.module_id=m.id
+LEFT JOIN author a ON a.cpanid=m.cpanid
+LEFT JOIN dist d ON d.id=dp.dist_id
 WHERE ".join(" AND ", @where)."
-GROUP BY id
+GROUP BY m.cpanid
 ORDER BY rdep_count DESC
 ";
 
@@ -59,7 +67,7 @@ ORDER BY rdep_count DESC
         push @res, $row;
     }
     my $resmeta = {};
-    $resmeta->{'table.fields'} = [qw/id rdep_count/];
+    $resmeta->{'table.fields'} = [qw/id name rdep_count/];
     [200, "OK", \@res, $resmeta];
 }
 
@@ -78,7 +86,7 @@ App::lcpan::Cmd::authors_by_rdep_count - List authors ranked by number of distri
 
 =head1 VERSION
 
-This document describes version 1.009 of App::lcpan::Cmd::authors_by_rdep_count (from Perl distribution App-lcpan), released on 2016-10-09.
+This document describes version 1.010 of App::lcpan::Cmd::authors_by_rdep_count (from Perl distribution App-lcpan), released on 2016-10-14.
 
 =head1 FUNCTIONS
 
@@ -99,6 +107,8 @@ Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
+=item * B<exclude_same_author> => I<bool>
+
 =item * B<index_name> => I<filename> (default: "index.db")
 
 Filename of index.
